<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Neveljavni polmer</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Ni rešitve</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Izberi entiteto ali regijo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Premakni entiteto ali referenco</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Nastavi drugo ogljišče</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Določi ciljno točko od referenčne točke</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Določi ciljno točko od izbora</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Premakni entiteto na željeno lokacijo</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Premakni referenčno točko</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Premakni izbor</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Premakni entiteto</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Urejanje gradnika &apos;%1&lt;br&gt;Ko boste končali, izberite&lt;i&gt;Gradnik &gt; Vrnitev na glasvno risbo&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Aktivno orodje:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">Nastavitve bloka</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Glavna orodja</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CAD orodja</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Entiteta je na zaklenjeni plasti.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Dolžina:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Entiteta ni blokovna referenca.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Entiteta ni črta ali lok.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Entiteta ni črta, lok ali lomljenka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Entiteta ni črta.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Entiteta ni lok ali krog.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Entiteta ni črta, lok ali krog.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Entiteta ni lok, krog ali elipsa.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Entiteta ni črta, lok, krog ali elipsa.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Entiteta ni črta, lok, krog ali elipsa ali lomljenka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Entiteta ni črta, lok, krog, elipsa ali krivulja.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Entiteta ni črta, lok, krog, elipsa, krivulja ali lomljenka.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Entiteta ni lomljenka.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Polmer je padel pod 0.0 po %1 kocentričnih krogih.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Polmer je padel pod 0.0 po %1 kocentričnih lokih.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>Vsaj dve točki sta identični.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>Nobena krožnica ni mogoča.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Noben lok ni možen.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>%1 neveljavnih segmentov.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Neveljavne elipse glavne / manjšinske: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Obnovi privzeto</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Vstavi simbol</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Premer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Lok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Stopinje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus/Minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Skoraj enako kot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Skoraj enako kot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Kvadrani koren</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>stari pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Moženje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Deljenje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Na 2 potenco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Besedilo na skladu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Izmerjena vrednost</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Center</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Poravnano</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Sredina</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Prilagodi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Zgoraj</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Izhodišče</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Spodaj</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation type="unfinished">Brez</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Nalagam prevode dodatkov...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Nalagam dodatke...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Inicializacija dodatkov...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Inicializacija dodatkov:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-inicializacija dodatkov...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objekti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Neznani objekti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Neznani objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Plasti</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Plast</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Razporeditve</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Razporeditev</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Tipi črt</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Tip črte</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Pogledi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Pogled</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Entiteta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Entitete</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3dPovršine</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3dPovršina</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Blokovne reference</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Blokovna referenca</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Blokovne reference ter atributi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Blokovna referenca in atributi</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Loki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Lok</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Atributi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Atribut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Definicije atributov</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Definicija atributa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Krožnice</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Krožnica</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Dimenzija</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Poravnane dimenzije</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Poravnana dimenzija</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Dimenzije kota</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Dimenzija kota</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Dimenzije premera</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Dimenzija premera</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Odmiki od koordinatnega središča</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Odmik od koordinatnega središča</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Rotirane dimenzije</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Rotirana dimenzija</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Radialne dimenzije</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Radialna dimenzija</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Šrafure</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Šrafura</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Slika</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Nosilke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Nosilka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Črte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Črta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Neskočne črte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Neskončna črta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Poltraki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Poltrak</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Točke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Točka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Lomljenke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Lomljenka</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Gruče</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Gradnik</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Sledi</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Sled</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Površine</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Površina</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Krivulje</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Krivulja</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Temelječe na besedilu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Besedila</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Besedilo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Izzseki </translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Izzsek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Neznane entitete</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Neznana entiteta</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Prve entitete ni mogoče porezat.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Entiteto ni mogoče porezat.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Druge entitete ni mogoče porezat.</translation>
    </message>
</context>
</TS>
